<?php defined('SYSTEM_PATH') || die('No direct script access allowed.');

// "application/controllers/cp/system/fields/advancedfeedback.php"

// Extend "CP_System_Fields_System_Controller" controller that contains all necessary functionality
// to display and edit custom fields. All we have to do here is add som basic information to
// the controller
class CP_System_Fields_AdvancedFeedback_Controller extends CP_System_Fields_System_Controller
{
	public function __construct()
	{
		parent::__construct();

		// Does user have permission to access this plugin?
		if ( !session::permission('fields_manage', 'advancedfeedback') )
		{
			view::noAccess();
		}

		// This will highlight the "Content" tab in the top navigation bar
		view::setCustomParam('section', 'content');

		// This will display navigation links we've added in the
		// "navigation.php" resource file ("settings" and "custom fields")
		view::setCustomParam('options', config::item('cp_top', 'navigation', 'content', 'links', 'content_advancedfeedback', 'links'));

		// Display current location in the "trail" navigation (right under the top navigation bar)
		view::setTrail('cp/system/plugins', __('content', 'system'));
		view::setTrail('cp/system/fields/advancedfeedback', __('advanced_feedback', 'advancedfeedback'));

		// Action hook in case someone else wants to add functionality to this plugin
		hook::action('system/controller/cp_system_fields_advancedfeedback');
	}

	public function index()
	{
		$this->browse();
	}

	// This controller will be executed when we view custom fields
	public function browse()
	{
		// Set title
		view::setTitle(__('fields', 'system_fields'));

		// Set trail
		view::setTrail('cp/system/fields/advancedfeedback/browse', __('fields', 'system_fields'));

		// Browse custom fields for 'advancedfeedback' plugin
		$this->browseFields('advancedfeedback');
	}

	// This controller will be executed when we edit or add custom field
	public function edit()
	{
		// Get URI vars
		$fieldID = (int)uri::segment(7);

		// Set title
		view::setTitle($fieldID ? __('edit_field', 'system_fields') : __('new_field', 'system_fields'));

		// Set trail
		view::setTrail('cp/system/fields/advancedfeedback/browse/', __('fields', 'system_fields'));

		// Hide certain elements on the page
		$hidden = array('vname' => '', 'html' => 0, 'in_search' => 0, 'in_search_advanced' => 0);
		if ( $fieldID )
		{
			// Get field details from the database
			$field = $this->fields_model->getField($fieldID);
			if ( $field )
			{
				switch ( $field['keyword'] )
				{
					// hide elements for the 'subject' field and set their default values
					case 'subject':
						$hidden['type'] = 'select';
						$hidden['required'] = 1;
						$hidden['multilang'] = 0;
						$hidden['in_search'] = 0;
						$hidden['system'] = 1;
						$hidden['config_custom_in_view'] = 1; // field will always be displayed
						break;

					// hide elements for the 'email' and 'message' fields and set their default values
					case 'email':
					case 'message':
						$hidden['type'] = 'textarea';
						$hidden['required'] = 1;
						$hidden['multilang'] = 0;
						$hidden['in_search'] = 0;
						$hidden['system'] = 1;
						$hidden['config_custom_in_view'] = 1; // field will always be displayed
						break;
				}
			}
		}

		// Additional field configuration array
		// It will allow us to show/hide custom fields on the feedback form
		$config = array(
			array(
				'label' => __('config_in_view', 'system_fields'),
				'keyword' => 'in_view',
				'type' => 'boolean',
				'rules' => array('intval'),
			),
		);

		// Run function from the extended controller to display/save custom field
		$this->editField('advancedfeedback', '', 0, $fieldID, $config, $hidden);
	}

	// This controller will be executed when we delete custom field
	public function delete()
	{
		// Get URI vars
		$fieldID = (int)uri::segment(7);

		// Run function from the extended controller to delete custom field
		$this->deleteField('advancedfeedback', '', 0, $fieldID);
	}
}
