<?php defined('SYSTEM_PATH') || die('No direct script access allowed.');

// "application/controllers/getintouch.php"

class GetInTouch_Controller extends Controller
{
	public function __construct()
	{
		parent::__construct();

		// Make sure feedback plugin is active
		if ( !config::item('active', 'advancedfeedback') )
		{
			error::show404();
		}
		// Do we have permission to access it?
		elseif ( !session::permission('feedback_access', 'advancedfeedback') )
		{
			view::noAccess();
		}

		// Action hook in case someone else wants to add functionality to this plugin
		hook::action('system/controller/getintouch');
	}

	public function index()
	{
		// Get feedback form fields
		// 'advancedfeedback' is the plugin name
		// '0' is the section ID
		// 'edit' parameter indicates that we're going to display the actual input elements
		// 'in_view' indicates that only fields we've selected will be loaded
		$fields = $this->fields_model->getFields('advancedfeedback', 0, 'edit', 'in_view');

		// Assign $fields variable to the view
		view::assign('fields', $fields);

		// Process form values
		if ( input::post('do_send_feedback') )
		{
			$this->_sendFeedback($fields);
		}

		// Set meta tags
		$this->metatags_model->setMetaTags('advancedfeedback', 'advancedfeedback_index', array(), true, true);

		// We can optionally set the title of the page which will override the one we set above
		//view::setTitle(__('advanced_feedback', 'advancedfeedback'), false);

		// Load view
		view::load('advancedfeedback/index');
	}

	protected function _sendFeedback($fields)
	{
		$rules = array(
			'data_email' => array(
				'label' => __('email', 'users'),
				'rules' => array('valid_email'),
			),
		);
		// Do we require security image?
		if ( config::item('captcha', 'advancedfeedback') == 1 || config::item('captcha', 'advancedfeedback') == 2 && !users_helper::isLoggedin() )
		{
			$rules['captcha'] = array('rules' => array('is_captcha'));
		}

		// Validate form values
		if ( !$this->fields_model->validateValues($fields, $rules) )
		{
			return false;
		}

		// Compose message variable from our custom fields
		$message = "";
		foreach ( $fields as $field )
		{
			if ( $field['keyword'] == 'subject' )
			{
				$subject = isset($field['items'][input::post('data_subject')]) ? $field['items'][input::post('data_subject')] : 'n/a';
			}
			else if ( $field['keyword'] != 'email' && input::post('data_' . $field['keyword']) !== false )
			{
				if ( is_array(input::post('data_' . $field['keyword'])) )
				{
					if ( isset($field['items']) )
					{
						$values = array();
						foreach ( input::post('data_' . $field['keyword']) as $k )
						{
							if ( isset($field['items'][$k]) )
							{
								$values[] = $field['items'][$k];
							}
						}
						$value = $values ? implode(', ', $values) : 'none';
					}
				}
				elseif ( $field['type'] == 'select' || $field['type'] == 'radio' )
				{
					$value = isset($field['items'][input::post('data_' . $field['keyword'])]) ? $field['items'][input::post('data_' . $field['keyword'])] : 'n/a';
				}
				else
				{
					$value = input::post('data_' . $field['keyword']);
				}
				$message .= $field['name'] . ': ' . $value . "\n";
			}
		}

		// Load email library
		loader::library('email');

		// Set 'reply' email
		$this->email->reply(input::post('data_email'));

		// Send email
		$this->email->sendEmail(config::item('email', 'advancedfeedback'), $subject, $message);

		// Success
		view::setInfo(__('message_sent', 'advancedfeedback'));
		router::redirect('getintouch');
	}
}
